package
Version:
v0.7.1
Opens a new window with list of versions in this module.
Published: Jul 13, 2020
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 2
Opens a new window with list of known importers.
Documentation
¶
const (
GateIO = "gate"
MXC = "mxc"
OKEx = "okex"
Huobi = "huobi"
)
type Candle struct {
Tickers []Ticker
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.